JSON API — springheel_jacky 1.0.0 documentation

Skip to main content

# JSON API

This is a listing of the various JSON endpoints exposed to springheel_jacky.

## Site

Keys
  aboutstr

    Whether or not the comic has an about page.

  archive_pagestr

    URL of the comic archive page.

  base_urlstr

    The base URL for this site.

  categorieslist of dict

    Categories on the site. If single is True, there will only be one entry. See Categories for a list of attributes belonging to these items.

  chapter_infodict

    Information about chapters in each category. See Chapters.

  characters_pagestr or bool

    If it exists, the URL of the characters page.

  copyright_statementstr

    HTML-formatted copyright block.

  countrystr

    The country from which this comic was published. This is mostly relevant if it is public domain.

  descriptionstr

    A short description of the site.

  diaspora_urlstr

    Diaspora* stream URL.

  extras_pagestr or bool

    If it exists, the URL of the extras page.

  generated_onfloat

    The date when this site was generated (Unix timestamp).

  header_filenamestr

    The filename for the site header banner.

  image_rename_patternstr

    The pattern used for renaming images.

  json_modestr

    Whether the site uses JSON files as input or Springheel’s original format.

  languagestr

    The site’s language (ISO 639-1 code).

  liberapay_handlestr

    Liberapay handle. Applied in the form of `https://liberapay.com/{liberapay_handle}`

  licensestr

    An HTML snippet with copyright information on the site.

  mastodon_urlstr

    Mastodon URL.

  navdirectionstr

    The metaphorical direction used for navigation arrows. Can be `ltr` or `rtl`.

  patreon_handlestr

    Patreon handle. Applied in the form of `https://www.patreon.com/{patreon_handle}`

  pump_urlstr

    Pump microblog URL.

  rename_imagesstr

    Whether or not to rename images when building the site.

  site_authorstr

    The author of this site.

  site_author_emailstr

    The author’s email, used for RSS feed generation. Will probably be fake.

  site_authorslist of str

    All persons whose work appears on the site.

  site_stylestr

    The site theme.

  site_titlestr

    The overall title of the site.

  site_typestr

    Whether the site has multiple “comics” or just one.

  social_iconsstr

    Whether or not to include social media links on each page.

  springheel_versionstr

    The version of Springheel used to build the site.

  store_pagestr or bool

    If it exists, the URL of the store page.

  tagslist of dict

    Tags associated with comics. See Tags for available attributes.

  tumblr_handlestr

    Tumblr blog. Applied like `https://{tumblr_handle}.tumblr.com`

  twitter_handlestr

    Twitter handle. Applied in the form of `https://twitter.com/{twitter_handle}`.

  zero_paddingstr

    To how many decimal places comic page numbers should be padded, if any.

## Categories

Keys
  categorystr

    The name of the category.

  charactersdict

    Character information for this category, if available. See Characters for available attributes.

  copyright_statementstr

    HTML-formatted copyright block.

  first_pagestr

    The newest page in the category.

  known_pageslist of str

    A list of all zero-padded page numbers in the category.

  known_pages_rawlist of str

    A list of all page numbers in the category as they were originally added to Springheel.

  known_pages_reallist of int, float, or tuple

    A list of all page numbers in this category converted to integers (or arrays of integers for multi-page spreads).

  last_pagestr

    The most recent page in the category.

  stripslist

    All strips included in this category. See Strips for a list of attributes belonging to these items.

## Strips

Keys
  alt_textstr

    A short piece of additional text associated with this strip. Not actually used as alt text.

  authorstr

    The author of this strip.

  author_emailstr

    The author’s email address. Will probably be fake.

  authorslist of str

    All authors listed separately, in case there are more than one.

  categorystr

    The name of the category associated with this strip.

  chapterstr or bool

    The strip’s chapter number, if available.

  commentarystr

    HTML-formatted commentary on this strip.

  copyright_statementstr

    HTML-formatted copyright block.

  datestr

    Duplicate of date_fmt

  date_fmtstr

    The date on which this strip was published.

  figcaptionstr

    `alt_text` formatted as an HTML figcaption.

  h1_titlestr

    The strip’s title as it appears in the main heading element (with page number and category).

  header_titlestr

    The same as h1_title.

  heightstr

    The height of the strip image.

  html_filenamestr

    An explanation about the purpose of this instance.

  imgstr

    The filename of the strip image.

  langstr

    The strip’s language.

  licensestr

    An explanation about the purpose of this instance.

  modestr

    Not currently used for anything.

  new_metastr

    The filename of the strip’s metadata file.

  new_transcrstr

    The filename of the strip’s transcript.

  pagestr

    The strip’s page number.

  page_paddedstr

    The strip’s page number, padded with zeroes.

  page_urlstr

    The strip’s URL.

  raw_commentslist of str

    The strip’s commentary in its original form.

  series_slugstr

    The strip’s category as a URL slug.

  sha256str

    SHA-256 checksum of the strip image.

  slugstr

    The strip’s URL slug.

  slugslist of str

    The category and strip title slugs used for file renaming.

  sourcestr

    The URL of a work on which this strip is based, or where it was originally posted.

  statlinestr

    An HTML block that appears below commentary, listing various metadata about the strip.

  tagslist of str

    An optional list of tags associated with this strip.

  titlestr

    The title of the strip.

  title_slugstr

    The title’s URL slug.

  transcript_cstr

    The HTML block with the strip’s transcript.

  urlstr

    Duplicate of page_url

  widthstr

    The strip image’s width.

  yearstr

    The year this strip was published.

## Characters

The `characters` key, if existent, has two keys:

Keys

itemslist of dict

  A list of character items.

urlstr

  The URL of the resultant characters page.

Each item in the `items` list has at minimum the following attributes:

Keys

namestr

  The character’s name.

descstr

  A description of the character.

imgstr

  An image filename representing a picture of the character.

More attributes may be available depending on the individual site.

## Tags

Keys

namestr

  The name of the tag.

urlstr

  The URL for the tag’s index.

## Chapters

Keys in this dictionary are the titles of Categories. Each contains a list of dictionaries indicating chapter numbers and, if available, titles:

Keys

numint

  The chapter number.

titlestr, optional

  The title of the chapter.